==> cscec5b-wzxt-impl-3.0.0-20210322.072605-167-sources.jar: com/ejianc/business/wzxt/controller/ExitApplyController.java <==
package com.ejianc.business.wzxt.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ExitApplyEntity;
import com.ejianc.business.wzxt.service.IExitApplyService;
import com.ejianc.business.wzxt.vo.ExitApplyVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 退场申请单
 *
 * @author generator
 */
@Controller
@RequestMapping("exitApply")
public class ExitApplyController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IExitApplyService service;

    @Autowired
    private IBillCodeApi billCodeApi;


    private static final String billCodeRule = "CSCEC5B_WZXT_EXIT_APPLY";


    /**
     * 关闭/取消申请
     * @Param saveorUpdateVO:
     * @Return com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.wzxt.vo.ExitApplyVO>
     * @Author songlx
     * @Date 2021-03-19
     **/
    @RequestMapping(value = "/upateApplyState", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ExitApplyVO> upateApplyState(@RequestBody ExitApplyVO saveorUpdateVO) {
        ExitApplyEntity entity = BeanMapper.map(saveorUpdateVO, ExitApplyEntity.class);
        entity.setApplyState(entity.getApplyState() == 1 ? 0 : 1);
        service.saveOrUpdate(entity);
        return CommonResponse.success("操作成功！");
    }

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ExitApplyVO> saveOrUpdate(@RequestBody ExitApplyVO saveorUpdateVO) {
        CommonResponse<String> codeBatchByRuleCode = billCodeApi.getCodeBatchByRuleCode(billCodeRule, InvocationInfoProxy.getTenantid());
        if (null == saveorUpdateVO.getId() && codeBatchByRuleCode.isSuccess()) {
            saveorUpdateVO.setBillCode(codeBatchByRuleCode.getData());
            saveorUpdateVO.setConfirmFlag(0);
            saveorUpdateVO.setApplyState(0);
        }
        ExitApplyEntity entity = BeanMapper.map(saveorUpdateVO, ExitApplyEntity.class);
        service.saveOrUpdate(entity, false);
        ExitApplyVO vo = BeanMapper.map(entity, ExitApplyVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ExitApplyVO> queryDetail(Long id) {
        ExitApplyEntity entity = service.selectById(id);
        ExitApplyVO vo = BeanMapper.map(entity, ExitApplyVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ExitApplyVO> vos) {
        service.removeByIds(vos.stream().map(ExitApplyVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ExitApplyVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例
         * 模糊搜索：单据编号、项目名称、合同名称、出资单位、编制人
         * 高级筛选：退场日期（时间区间）；单据状态（标准筛选）；*/
        param.setFuzzyFields(Arrays.asList("billCode", "projectName", "contractName", "supplierName", "employeeName"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<ExitApplyEntity> page = service.queryPage(param, false);
        IPage<ExitApplyVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ExitApplyVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    /**
     * 导出
     * @Param param: 参数
     * @Param response: 文件流
     * @Return void
     * @Author songlx
     * @Date 2021-03-20
     **/
    @PostMapping("excelExport")
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        service.excelExport(param,response);
    }
}

==> cscec5b-wzxt-impl-3.0.0-20210322.084122-169-sources.jar: com/ejianc/business/wzxt/controller/ExitApplyController.java <==
package com.ejianc.business.wzxt.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ExitApplyEntity;
import com.ejianc.business.wzxt.service.IExitApplyService;
import com.ejianc.business.wzxt.vo.ExitApplyDetailVO;
import com.ejianc.business.wzxt.vo.ExitApplyVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 退场申请单
 *
 * @author generator
 */
@Controller
@RequestMapping("exitApply")
public class ExitApplyController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IExitApplyService service;

    @Autowired
    private IBillCodeApi billCodeApi;


    private static final String billCodeRule = "CSCEC5B_WZXT_EXIT_APPLY";


    /**
     * 关闭/取消申请
     *
     * @Param saveorUpdateVO:
     * @Return com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.wzxt.vo.ExitApplyVO>
     * @Author songlx
     * @Date 2021-03-19
     **/
    @RequestMapping(value = "/upateApplyState", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ExitApplyVO> upateApplyState(@RequestBody ExitApplyVO saveorUpdateVO) {
        ExitApplyEntity entity = BeanMapper.map(saveorUpdateVO, ExitApplyEntity.class);
        entity.setApplyState(entity.getApplyState() == 1 ? 0 : 1);
        service.saveOrUpdate(entity);
        return CommonResponse.success("操作成功！");
    }

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ExitApplyVO> saveOrUpdate(@RequestBody ExitApplyVO saveorUpdateVO) {
        CommonResponse<String> codeBatchByRuleCode = billCodeApi.getCodeBatchByRuleCode(billCodeRule, InvocationInfoProxy.getTenantid());
        if (null == saveorUpdateVO.getId() && codeBatchByRuleCode.isSuccess()) {
            saveorUpdateVO.setBillCode(codeBatchByRuleCode.getData());
            saveorUpdateVO.setConfirmFlag(0);
            saveorUpdateVO.setApplyState(0);
        }
        ExitApplyEntity entity = BeanMapper.map(saveorUpdateVO, ExitApplyEntity.class);
        service.saveOrUpdate(entity, false);
        ExitApplyVO vo = BeanMapper.map(entity, ExitApplyVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ExitApplyVO> queryDetail(Long id) {
        ExitApplyEntity entity = service.selectById(id);
        ExitApplyVO vo = BeanMapper.map(entity, ExitApplyVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ExitApplyVO> vos) {
        service.removeByIds(vos.stream().map(ExitApplyVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ExitApplyVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例
         * 模糊搜索：单据编号、项目名称、合同名称、出资单位、编制人
         * 高级筛选：退场日期（时间区间）；单据状态（标准筛选）；*/
        param.setFuzzyFields(Arrays.asList("billCode", "projectName", "contractName", "supplierName", "employeeName"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<ExitApplyEntity> page = service.queryPage(param, false);
        IPage<ExitApplyVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ExitApplyVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    /**
     * 导出
     *
     * @Param param: 参数
     * @Param response: 文件流
     * @Return void
     * @Author songlx
     * @Date 2021-03-20
     **/
    @PostMapping("excelExport")
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        service.excelExport(param, response);
    }


    /**
     * 新增,参照材料库,查询并补录材料库在场和退场数据信息
     *
     * @Param exitApplyVO: 合同id 表体材料库信息
     * @Return com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.wzxt.vo.ExitApplyVO>
     * @Author songlx
     * @Date 2021-03-22
     **/
    @RequestMapping(value = "/queryForAddDeatil", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<ExitApplyDetailVO>> queryForAddDeatil(@RequestBody ExitApplyVO exitApplyVO) {
        String contractId = exitApplyVO.getContractId();
        List<ExitApplyDetailVO> exitApplyDetail = exitApplyVO.getExitApplyDetail();
        if (StringUtils.isNotEmpty(contractId) && !CollectionUtils.isEmpty(exitApplyDetail)) {
            List<Long> materialIds = exitApplyDetail.stream().map(ExitApplyDetailVO::getMaterialId).collect(Collectors.toList());
            List<ExitApplyDetailVO> exitApplyDetailVOList = service.queryForAddDeatil(contractId, materialIds, InvocationInfoProxy.getTenantid());
            if (!CollectionUtils.isEmpty(exitApplyDetailVOList)) {
                Map<Long, ExitApplyDetailVO> detailVOMap = exitApplyDetailVOList.stream().collect(Collectors.toMap(ExitApplyDetailVO::getMaterialId, exitApplyDetailVO -> exitApplyDetailVO));
                exitApplyDetail.stream().forEach(item -> {
                            Long materialId = item.getMaterialId();
                            ExitApplyDetailVO vo = detailVOMap.get(materialId);
                            if (null != vo) {
                                item.setExitedNum(vo.getExitedNum());
                                item.setOnRentNum(vo.getOnRentNum());
                            } else {
                                item.setExitedNum(item.getExitedNum() == null ? BigDecimal.ZERO : item.getExitedNum());
                                item.setOnRentNum(item.getOnRentNum() == null ? BigDecimal.ZERO : item.getOnRentNum());
                            }
                        }
                );
            }
        }
        return CommonResponse.success("查询成功！", exitApplyDetail);
    }
}
